using System;
using System.Collections.Generic;
using System.Text;
using System.ComponentModel;

namespace WaveData
{
    /// <summary>
    /// Wrapper around a double to provide change notifications.
    /// </summary>
    class Amplitude : INotifyPropertyChanged
    {
        #region Fields

        /// <summary>
        /// Current value of the Value property.
        /// </summary>
        private double amplitudePropertyValue;

        #endregion

        #region Properties

        /// <summary>
        /// The current amplitude value.
        /// </summary>
        public double Value
        {
            get { return amplitudePropertyValue; }
            set
            {
                if (amplitudePropertyValue != value)
                {
                    amplitudePropertyValue = value;
                    OnPropertyChanged("Amplitude");
                }
            }
        }

        #endregion

        #region ToString

        /// <summary>
        /// Current value as a string.
        /// </summary>
        /// <returns>Current value as a string</returns>
        public override string ToString()
        {
            return Value.ToString();
        }

        #endregion

        #region Events

        /// <summary>
        /// Raised when a property value changes.
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        #endregion

        #region Private methods

        /// <summary>
        /// Raises the PropertyChanged event.
        /// </summary>
        /// <param name="propertyName">Name of property that changed.</param>
        private void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}
